@@ -259,7 +259,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.FC6_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -317,7 +316,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.FC6_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -375,7 +373,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.FC6_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -433,7 +430,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.F10_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -492,7 +488,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.F10_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -553,7 +548,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.F10_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -614,7 +608,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.F10_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -657,7 +650,7 @@ commandMap = {
         "autopart": autopart.F12_AutoPart,
         "autostep": autostep.FC3_AutoStep,
         "bootloader": bootloader.F14_Bootloader,
-        "cdrom": method.F13_Method,
+        "cdrom": method.F14_Method,
         "clearpart": clearpart.FC3_ClearPart,
         "cmdline": displaymode.FC3_DisplayMode,
         "device": device.F8_Device,
@@ -670,13 +663,12 @@ commandMap = {
         "graphical": displaymode.FC3_DisplayMode,
         "group": group.F12_Group,
         "halt": reboot.FC6_Reboot,
-        "harddrive": method.F13_Method,
+        "harddrive": method.F14_Method,
         "ignoredisk": ignoredisk.F14_IgnoreDisk,
         "install": upgrade.F11_Upgrade,
-        "interactive": interactive.FC3_Interactive,
+        "interactive": interactive.F14_Interactive,
         "iscsi": iscsi.F10_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -685,13 +677,13 @@ commandMap = {
         "monitor": monitor.F10_Monitor,
         "multipath": multipath.FC6_MultiPath,
         "network": network.F9_Network,
-        "nfs": method.F13_Method,
+        "nfs": method.F14_Method,
         "part": partition.F14_Partition,
         "partition": partition.F14_Partition,
         "poweroff": reboot.FC6_Reboot,
         "raid": raid.F14_Raid,
         "reboot": reboot.FC6_Reboot,
-        "repo": repo.F13_Repo,
+        "repo": repo.F14_Repo,
         "rescue": rescue.F10_Rescue,
         "rootpw": rootpw.F8_RootPw,
         "selinux": selinux.FC3_SELinux,
@@ -703,7 +695,7 @@ commandMap = {
         "timezone": timezone.FC6_Timezone,
         "updates": updates.F7_Updates,
         "upgrade": upgrade.F11_Upgrade,
-        "url": method.F13_Method,
+        "url": method.F14_Method,
         "user": user.F12_User,
         "vnc": vnc.F9_Vnc,
         "volgroup": volgroup.FC3_VolGroup,
@@ -836,7 +828,7 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.FC6_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
+        "key": key.RHEL5_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "langsupport": langsupport.FC5_LangSupport,
@@ -897,7 +889,6 @@ commandMap = {
         "interactive": interactive.FC3_Interactive,
         "iscsi": iscsi.F10_Iscsi,
         "iscsiname": iscsiname.FC6_IscsiName,
-        "key": key.F7_Key,
         "keyboard": keyboard.FC3_Keyboard,
         "lang": lang.FC3_Lang,
         "logging": logging.FC6_Logging,
@@ -1103,7 +1094,7 @@ dataMap = {
         "NetworkData": network.F8_NetworkData,
         "PartData": partition.F14_PartData,
         "RaidData": raid.F14_RaidData,
-        "RepoData": repo.F13_RepoData,
+        "RepoData": repo.F14_RepoData,
         "SshPwData": sshpw.F13_SshPwData,
         "UserData": user.F12_UserData,
         "VolGroupData": volgroup.FC3_VolGroupData,
